@@ -1,6 +1,3 @@
-# coding: utf-8
-
-
 # This module defines firetasks for modifying molecular geometries
 
 import copy
@@ -80,7 +77,9 @@ class PerturbGeometry(FiretaskBase):
         elif fw_spec.get("prev_calc_molecule"):
             mol = fw_spec.get("prev_calc_molecule")
         else:
-            raise KeyError("No molecule present; add as an optional param or check fw_spec")
+            raise KeyError(
+                "No molecule present; add as an optional param or check fw_spec"
+            )
 
         if self.get("mode") is not None:
             mode = self.get("mode")
@@ -95,4 +94,4 @@ class PerturbGeometry(FiretaskBase):
 
         update_spec = {"prev_calc_molecule": mol_copy}
 
-        return FWAction(update_spec=update_spec)
\ No newline at end of file
+        return FWAction(update_spec=update_spec)
