@@ -11,7 +11,7 @@ __author__ = "Kiran Mathew"
 __credits__ = "Anubhav Jain"
 __email__ = "kmathew@lbl.gov"
 
-MODULE_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)))
+MODULE_DIR = os.path.dirname(os.path.abspath(__file__))
 DB_DIR = os.path.join(MODULE_DIR, "..", "common", "test_files")
 
 DEBUG_MODE = (
@@ -85,7 +85,7 @@ class AtomateTest(unittest.TestCase):
             if hasattr(self, "lp"):
                 self.lp.reset("", require_password=False)
                 db = self.get_task_database()
-                for coll in db.collection_names():
+                for coll in db.list_collection_names():
                     if coll != "system.indexes":
                         db[coll].drop()
             shutil.rmtree(self.scratch_dir)
