@@ -137,24 +137,25 @@ def get_logger(
 
 
 def get_meta_from_structure(structure):
-   if isinstance(structure, TransformedStructure):
-       structure = structure.final_structure
+    if isinstance(structure, TransformedStructure):
+        structure = structure.final_structure
+
+    comp = structure.composition
+    elsyms = sorted({e.symbol for e in comp.elements})
+    meta = {
+        "nsites": structure.num_sites,
+        "elements": elsyms,
+        "nelements": len(elsyms),
+        "formula": comp.formula,
+        "formula_pretty": comp.reduced_formula,
+        "formula_reduced_abc": Composition(comp.reduced_formula).alphabetical_formula,
+        "formula_anonymous": comp.anonymized_formula,
+        "chemsys": "-".join(elsyms),
+        "is_ordered": structure.is_ordered,
+        "is_valid": structure.is_valid(),
+    }
+    return meta
 
-   comp = structure.composition
-   elsyms = sorted({e.symbol for e in comp.elements})
-   meta = {
-       "nsites": structure.num_sites,
-       "elements": elsyms,
-       "nelements": len(elsyms),
-       "formula": comp.formula,
-       "formula_pretty": comp.reduced_formula,
-       "formula_reduced_abc": Composition(comp.reduced_formula).alphabetical_formula,
-       "formula_anonymous": comp.anonymized_formula,
-       "chemsys": "-".join(elsyms),
-       "is_ordered": structure.is_ordered,
-       "is_valid": structure.is_valid(),
-   }
-   return meta
 
 def get_fws_and_tasks(workflow, fw_name_constraint=None, task_name_constraint=None):
     """
@@ -272,7 +273,7 @@ def get_wf_from_spec_dict(structure, wfspec, common_param_updates=None):
         fws.append(cls_(structure=structure, **params))
 
     wfname = (
-        "{}:{}".format(structure.composition.reduced_formula, wfspec["name"])
+        f"{structure.composition.reduced_formula}:{wfspec['name']}"
         if wfspec.get("name")
         else structure.composition.reduced_formula
     )
