@@ -1,14 +1,14 @@
 import numpy as np
-from atomate.utils.utils import get_database, get_logger
 from tqdm import tqdm
 
+from atomate.utils.utils import get_database, get_logger
+
 logger = get_logger(__name__)
 
-__author__ = 'Shyue Ping Ong <ongsp@uscd.edu>, Anubhav Jain <ajain@lbl.gov>'
+__author__ = "Shyue Ping Ong <ongsp@uscd.edu>, Anubhav Jain <ajain@lbl.gov>"
 
 
 class DielectricBuilder:
-
     def __init__(self, materials_write):
         """
         Starting with an existing materials collection, adds some averages and
@@ -21,9 +21,14 @@ class DielectricBuilder:
 
     def run(self):
         logger.info("EpsilonBuilder starting...")
-        q = {"dielectric": {"$exists": True}, "dielectric.eps_ionic_avg": {"$exists": False}}
+        q = {
+            "dielectric": {"$exists": True},
+            "dielectric.eps_ionic_avg": {"$exists": False},
+        }
 
-        for m in tqdm(self._materials.find(q, projection=["material_id", "dielectric"])):
+        for m in tqdm(
+            self._materials.find(q, projection=["material_id", "dielectric"])
+        ):
             try:
                 eps = m["dielectric"]
                 d = {}
@@ -32,25 +37,33 @@ class DielectricBuilder:
 
                 d["dielectric.epsilon_ionic_avg"] = float(np.average(eig_ionic))
                 d["dielectric.epsilon_static_avg"] = float(np.average(eig_static))
-                d["dielectric.epsilon_avg"] = d["dielectric.epsilon_ionic_avg"] + \
-                                              d["dielectric.epsilon_static_avg"]
-                d["dielectric.has_neg_eps"] = bool(np.any(eig_ionic < -0.1) or
-                                                   np.any(eig_static < -0.1))
+                d["dielectric.epsilon_avg"] = (
+                    d["dielectric.epsilon_ionic_avg"]
+                    + d["dielectric.epsilon_static_avg"]
+                )
+                d["dielectric.has_neg_eps"] = bool(
+                    np.any(eig_ionic < -0.1) or np.any(eig_static < -0.1)
+                )
 
-                self._materials.update_one({"material_id": m["material_id"]}, {"$set": d})
+                self._materials.update_one(
+                    {"material_id": m["material_id"]}, {"$set": d}
+                )
 
-            except:
+            except Exception:
                 import traceback
+
                 logger.exception(traceback.format_exc())
 
         logger.info("EpsilonBuilder finished processing.")
 
     def reset(self):
         logger.info("Resetting EpsilonBuilder")
-        keys = ["dielectric.epsilon_ionic_avg",
-                "dielectric.epsilon_static_avg",
-                "dielectric.epsilon_avg",
-                "dielectric.has_neg_eps"]
+        keys = [
+            "dielectric.epsilon_ionic_avg",
+            "dielectric.epsilon_static_avg",
+            "dielectric.epsilon_avg",
+            "dielectric.has_neg_eps",
+        ]
 
         self._materials.update_many({}, {"$unset": {k: "" for k in keys}})
         logger.info("Finished resetting EpsilonBuilder")
