@@ -2,12 +2,12 @@
 This class contains common functions for builders
 """
 
-__author__ = 'Anubhav Jain <ajain@lbl.gov>'
+__author__ = "Anubhav Jain <ajain@lbl.gov>"
 
 
 def dbid_to_str(prefix, dbid):
     # converts int dbid to string (adds prefix)
-    return "{}-{}".format(prefix, dbid)
+    return f"{prefix}-{dbid}"
 
 
 def dbid_to_int(dbid):
