@@ -11,7 +11,6 @@ import os
 import re
 import traceback
 import warnings
-from collections import OrderedDict
 from fnmatch import fnmatch
 
 import numpy as np
@@ -235,10 +234,10 @@ class VaspDrone(AbstractDrone):
             file_pattern (string): files to be searched for
 
         Returns:
-            OrderedDict of the names of the files to be processed further.
-            The key is set from list of run types: self.runs
+            dict: names of the files to be processed further. The key is set from list
+                of run types: self.runs
         """
-        processed_files = OrderedDict()
+        processed_files = {}
         files = os.listdir(path)
         for r in self.runs:
             # try subfolder schema
@@ -560,9 +559,7 @@ class VaspDrone(AbstractDrone):
                         d[file] = data.as_dict()
                     except Exception:
                         raise ValueError(
-                            "Failed to parse {} at {}.".format(
-                                file, d["output_file_paths"][file]
-                            )
+                            f"Failed to parse {file} at {d['output_file_paths'][file]}."
                         )
 
         # parse force constants
@@ -701,10 +698,8 @@ class VaspDrone(AbstractDrone):
                     desired_force_convergence = np.inf
                 if max_drift > desired_force_convergence:
                     warning_msgs.append(
-                        "Drift ({}) > desired force convergence ({}), "
-                        "structure likely not converged to desired accuracy.".format(
-                            drift, desired_force_convergence
-                        )
+                        f"Drift ({drift}) > desired force convergence ({desired_force_convergence}), "
+                        "structure likely not converged to desired accuracy."
                     )
 
             s = Structure.from_dict(d["output"]["structure"])
