@@ -8,16 +8,6 @@ import os
 import shutil
 import warnings
 
-from fireworks import FiretaskBase, explicit_serialize, FWAction
-from fireworks.utilities.fw_serializers import DATETIME_HANDLER
-from monty.json import jsanitize
-from monty.os.path import zpath
-from monty.serialization import loadfn
-
-from atomate.common.firetasks.glue_tasks import get_calc_loc
-from atomate.utils.utils import env_chk, get_meta_from_structure
-from atomate.vasp.config import VASP_OUTPUT_FILES
-from atomate.vasp.database import VaspCalcDb, put_file_in_gridfs
 from custodian import Custodian
 from custodian.lobster.handlers import (
     ChargeSpillingValidator,
@@ -25,8 +15,18 @@ from custodian.lobster.handlers import (
     LobsterFilesValidator,
 )
 from custodian.lobster.jobs import LobsterJob
+from fireworks import FiretaskBase, FWAction, explicit_serialize
+from fireworks.utilities.fw_serializers import DATETIME_HANDLER
+from monty.json import jsanitize
+from monty.os.path import zpath
+from monty.serialization import loadfn
 from pymatgen.core.structure import Structure
-from pymatgen.io.lobster import Lobsterout, Lobsterin
+from pymatgen.io.lobster import Lobsterin, Lobsterout
+
+from atomate.common.firetasks.glue_tasks import get_calc_loc
+from atomate.utils.utils import env_chk, get_meta_from_structure
+from atomate.vasp.config import VASP_OUTPUT_FILES
+from atomate.vasp.database import VaspCalcDb, put_file_in_gridfs
 
 __author__ = "Janine George, Guido Petretto"
 __email__ = "janine.george@uclouvain.be, guido.petretto@uclouvain.be"
@@ -163,7 +163,13 @@ class RunLobster(FiretaskBase):
         c.run()
 
         if os.path.exists(zpath("custodian.json")):
-            stored_custodian_data = {"custodian": loadfn(zpath("custodian.json"))}
+            if os.path.exists(zpath("FW_offline.json")):
+                import json
+
+                with open(zpath("custodian.json")) as f:
+                    stored_custodian_data = {"custodian": json.load(f)}
+            else:
+                stored_custodian_data = {"custodian": loadfn(zpath("custodian.json"))}
             return FWAction(stored_data=stored_custodian_data)
 
 
@@ -200,11 +206,14 @@ class LobsterRunToDb(FiretaskBase):
     std_additional_outputs = [
         "ICOHPLIST.lobster",
         "ICOOPLIST.lobster",
+        "ICOBILIST.lobster",
         "COHPCAR.lobster",
         "COOPCAR.lobster",
         "GROSSPOP.lobster",
         "CHARGE.lobster",
         "DOSCAR.lobster",
+        "MadelungEnergies.lobster",
+        "SitePotentials.lobster",
     ]
 
     def __init__(self, *args, **kwargs):
@@ -264,7 +273,7 @@ class LobsterRunToDb(FiretaskBase):
             task_doc.update(additional_fields)
 
         task_doc.update(get_meta_from_structure(struct))
-        if vasp_calc_dir != None:
+        if vasp_calc_dir is not None:
             task_doc["vasp_dir_name"] = vasp_calc_dir
         else:
             task_doc["vasp_dir_name"] = vasp_calc_loc["path"]
@@ -281,7 +290,7 @@ class LobsterRunToDb(FiretaskBase):
         db_file = env_chk(self.get("db_file"), fw_spec)
 
         # db insertion or taskdoc dump
-        if not db_file:
+        if not db_file or os.path.exists(zpath("FW_offline.json")):
             with open("task_lobster.json", "w") as f:
                 f.write(json.dumps(task_doc, default=DATETIME_HANDLER))
         else:
@@ -339,7 +348,7 @@ class RunLobsterFake(FiretaskBase):
         # Check lobsterin
         if self.get("check_lobsterin", True):
             ref_lobsterin = Lobsterin.from_file(
-                os.path.join(self["ref_dir"], "inputs", "lobsterin")
+                os.path.join(self["ref_dir"], "inputs", "lobsterin.gz")
             )
             params_to_check = self.get("params_to_check", [])
             for p in params_to_check:
