@@ -1,8 +1,3 @@
-from monty.os.path import zpath
-from monty.serialization import loadfn
-
-from atomate.vasp.config import HALF_KPOINTS_FIRST_RELAX
-
 """
 This module defines tasks that support running vasp in various ways.
 """
@@ -33,12 +28,14 @@ from custodian.vasp.handlers import (
 from custodian.vasp.jobs import VaspJob, VaspNEBJob
 from custodian.vasp.validators import VaspFilesValidator, VasprunXMLValidator
 from fireworks import FiretaskBase, FWAction, explicit_serialize
+from monty.os.path import zpath
+from monty.serialization import loadfn
 from pymatgen.electronic_structure.boltztrap import BoltztrapRunner
 from pymatgen.io.vasp import Incar, Kpoints, Poscar, Potcar
 from pymatgen.io.vasp.sets import get_vasprun_outcar
 
 from atomate.utils.utils import env_chk, get_logger
-from atomate.vasp.config import CUSTODIAN_MAX_ERRORS
+from atomate.vasp.config import CUSTODIAN_MAX_ERRORS, HALF_KPOINTS_FIRST_RELAX
 
 __author__ = "Anubhav Jain <ajain@lbl.gov>"
 __credits__ = "Shyue Ping Ong <ong.sp>"
@@ -386,7 +383,9 @@ class RunVaspFake(FiretaskBase):
         self._generate_outputs()
 
     def _verify_inputs(self):
-        user_incar = Incar.from_file(os.path.join(os.getcwd(), "INCAR"))
+        cwd = os.getcwd()
+        user_incar = Incar.from_file(os.path.join(cwd, "INCAR"))
+        input_path = os.path.join(self["ref_dir"], "inputs")
 
         # Carry out some BASIC tests.
 
@@ -405,7 +404,7 @@ class RunVaspFake(FiretaskBase):
 
         # Check KPOINTS
         if self.get("check_kpoints", True):
-            user_kpoints = Kpoints.from_file(os.path.join(os.getcwd(), "KPOINTS"))
+            user_kpoints = Kpoints.from_file(os.path.join(cwd, "KPOINTS"))
             ref_kpoints = Kpoints.from_file(
                 os.path.join(self["ref_dir"], "inputs", "KPOINTS")
             )
@@ -414,17 +413,13 @@ class RunVaspFake(FiretaskBase):
                 or user_kpoints.num_kpts != ref_kpoints.num_kpts
             ):
                 raise ValueError(
-                    "KPOINT files are inconsistent! Paths are:\n{}\n{} with kpoints {} and {}".format(
-                        os.getcwd(),
-                        os.path.join(self["ref_dir"], "inputs"),
-                        user_kpoints,
-                        ref_kpoints,
-                    )
+                    f"KPOINT files are inconsistent! Paths are:\n{cwd}\n{input_path} "
+                    f"with kpoints {user_kpoints} and {ref_kpoints}"
                 )
 
         # Check POSCAR
         if self.get("check_poscar", True):
-            user_poscar = Poscar.from_file(os.path.join(os.getcwd(), "POSCAR"))
+            user_poscar = Poscar.from_file(os.path.join(cwd, "POSCAR"))
             ref_poscar = Poscar.from_file(
                 os.path.join(self["ref_dir"], "inputs", "POSCAR")
             )
@@ -433,22 +428,18 @@ class RunVaspFake(FiretaskBase):
                 or user_poscar.site_symbols != ref_poscar.site_symbols
             ):
                 raise ValueError(
-                    "POSCAR files are inconsistent! Paths are:\n{}\n{}".format(
-                        os.getcwd(), os.path.join(self["ref_dir"], "inputs")
-                    )
+                    f"POSCAR files are inconsistent! Paths are:\n{cwd}\n{input_path}"
                 )
 
         # Check POTCAR
         if self.get("check_potcar", True):
-            user_potcar = Potcar.from_file(os.path.join(os.getcwd(), "POTCAR"))
+            user_potcar = Potcar.from_file(os.path.join(cwd, "POTCAR"))
             ref_potcar = Potcar.from_file(
                 os.path.join(self["ref_dir"], "inputs", "POTCAR")
             )
             if user_potcar.symbols != ref_potcar.symbols:
                 raise ValueError(
-                    "POTCAR files are inconsistent! Paths are:\n{}\n{}".format(
-                        os.getcwd(), os.path.join(self["ref_dir"], "inputs")
-                    )
+                    f"POTCAR files are inconsistent! Paths are:\n{cwd}\n{input_path}"
                 )
 
         logger.info("RunVaspFake: verified inputs successfully")
