@@ -8,7 +8,7 @@ __author__ = "Anubhav Jain, Shyue Ping Ong, Kiran Mathew"
 __email__ = "ajain@lbl.gov, ongsp@eng.ucsd.edu, kmathew@lbl.gov"
 
 
-module_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)))
+module_dir = os.path.dirname(os.path.abspath(__file__))
 
 
 def get_wf(
