@@ -88,9 +88,9 @@ def get_wf_raman_spectra(
     fw_analysis = Firework(
         RamanTensorToDb(db_file=db_file),
         parents=fws[:],
-        name="{}-{}".format(structure.composition.reduced_formula, "raman analysis"),
+        name=f"{structure.composition.reduced_formula}-raman analysis",
     )
     fws.append(fw_analysis)
 
-    wfname = "{}:{}".format(structure.composition.reduced_formula, "raman spectra")
+    wfname = f"{structure.composition.reduced_formula}:raman spectra"
     return Workflow(fws, name=wfname)
